usbatm cxacru.c,1.24,1.25

kagan at infradead.org kagan at infradead.org
Fri Apr 1 07:32:43 EST 2005


Update of /home/cvs/usbatm
In directory phoenix.infradead.org:/tmp/cvs-serv10191

Modified Files:
	cxacru.c 
Log Message:
Convert timeouts from jiffies to msecs.

Index: cxacru.c
===================================================================
RCS file: /home/cvs/usbatm/cxacru.c,v
retrieving revision 1.24
retrieving revision 1.25
diff -u -r1.24 -r1.25
--- cxacru.c	1 Apr 2005 12:17:57 -0000	1.24
+++ cxacru.c	1 Apr 2005 12:32:40 -0000	1.25
@@ -66,11 +66,8 @@
 /* Values */
 #define SDRAM_ENA	0x1
 
 /* Timeout in jiffies */
 #define CMD_TIMEOUT	(2 * HZ)
 #define CMD_TIMEOUT_MS  2000
 #define DATA_TIMEOUT	(2 * HZ)
 #define DATA_TIMEOUT_MS 2000
 
 /* commands for interaction with the modem through the control channel before
  * firmware is loaded  */
@@ -195,7 +192,7 @@
 	int status;
 
 	init_timer(&timer);
-	timer.expires = jiffies + CMD_TIMEOUT;
+	timer.expires = jiffies + msecs_to_jiffies(CMD_TIMEOUT);
 	timer.data = (unsigned long) urb;
 	timer.function = cxacru_timeout_kill;
 	add_timer(&timer);
@@ -496,7 +493,7 @@
 		offd += stride;
 		if ((offb >= PAGE_SIZE) || (offd >= size)) {
 			ret = usb_bulk_msg(usb_dev, usb_sndbulkpipe(usb_dev, CXACRU_EP_CMD),
-					   buf, offb, NULL, CMD_TIMEOUT_MS);
+					   buf, offb, NULL, CMD_TIMEOUT);
 			if (ret < 0) {
 				dbg("sending fw %#x failed", fw);
 				goto cleanup;
@@ -66,11 +66,8 @@
 #define SDRAM_ENA	0x1
 
-/* Timeout in jiffies */
-#define CMD_TIMEOUT	(2 * HZ)
-#define CMD_TIMEOUT_MS  2000
-#define DATA_TIMEOUT	(2 * HZ)
-#define DATA_TIMEOUT_MS 2000
+/* Timeout in msecs */
+#define CMD_TIMEOUT	2000
 
 /* commands for interaction with the modem through the control channel before




More information about the Usbatm-commits mailing list